import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";
import "./globals.css";
import { Providers } from './providers'
import { fonts } from './fonts'
import Navbar from "./components/common/Navbar";
import Footer from "./components/common/Footer";
import ColorModeToggle from "./components/ColorModeToggle";
import ConsentPopup from "./components/ConsentPopup";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "My Blog",
  description: "Tech, podcasts, and resources for curious minds.",
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en" className={fonts.rubik.variable}>
      <body
        className={`${geistSans.variable} ${geistMono.variable} antialiased`}
      >
        <Providers>
          <Navbar />        {/* Global Navbar */}
          <ColorModeToggle />

          <main>{children}</main>
                  <ConsentPopup />

          <Footer />      
        </Providers>
      </body>
    </html>
  );
}
